Description: Fix spelling errors.
Author: Sascha Steinbiss <sascha@steinbiss.name> 
--- a/auxprogs/bam2hints/bam2hints.cc
+++ b/auxprogs/bam2hints/bam2hints.cc
@@ -515,7 +515,7 @@
 	 << "                          You should generate exonpart hints from RNA-Seq using wiggle (.wig) input to wig2hints.\n"
          << "  --ep_cutoff=n      -e   this many bp are cut off of each exonpart hint at end of alignment (set to " << EpCutoff << ")\n"
          << "  --source=s         -s   source identifier (set to '" << Source << "')\n"
-         << "  --intronsonly      -I   only retreive intron hints (e.g. because the exon(part) hints are retreived by converting to a wig track, set to " << OnOff(IntOnly) << ")\n"
+         << "  --intronsonly      -I   only retrieve intron hints (e.g. because the exon(part) hints are retrieved by converting to a wig track, set to " << OnOff(IntOnly) << ")\n"
 	 << "                          deprecated as this is the default now\n"
          << "  --nomult           -n   do not summarize multiple identical intron hints to a single one (set to " << OnOff(!Mult) << ")\n"
          << "  --remove_redundant -r   only keep the strongest hint for a region (set to " << OnOff(RemRed) << ")\n"
--- a/auxprogs/homGeneMapping/src/main.cc
+++ b/auxprogs/homGeneMapping/src/main.cc
@@ -130,7 +130,7 @@
 	// check if the boost library is installed (only required for option --printHomologs)
 	if(!homGeneFile.empty()){
 #ifndef BOOST
-	    throw ProjectError("The option --printHomologs requires the boost C++ libary.\n"
+	    throw ProjectError("The option --printHomologs requires the boost C++ library.\n"
                                "Please install the boost library, e.g. using the APT package manager\n\n"
                                "sudo apt-get install libboost-graph-dev\n\n"
                                "Then edit the Makefile by setting the flag BOOST = true and recompile homGeneMapping.\n");
--- a/include/statemodel.hh
+++ b/include/statemodel.hh
@@ -144,7 +144,7 @@
 
 /*
  * classes Snippet*
- * intelligently store and retreive the sequence emission probabilities of the sequence from a to b
+ * intelligently store and retrieve the sequence emission probabilities of the sequence from a to b
  * for common pairs of a and b
  */
 class SnippetListItem {
--- a/scripts/blat2hints.pl
+++ b/scripts/blat2hints.pl
@@ -26,7 +26,7 @@
 $usage .= "  --maxQgaplen=n     maximum length of gap in query (cDNA) sequence (default 5)\n";
 $usage .= "  --ep_cutoff=n      this many bp are cut off of each exonpart hint at end of alignment (default 10)\n";
 $usage .= "  --source=s         source identifier (default 'E')\n";
-$usage .= "  --intronsonly      only retrieve intron hints (e.g. because the exon(part) hints are retreived by converting to a wig track, default: off)\n";
+$usage .= "  --intronsonly      only retrieve intron hints (e.g. because the exon(part) hints are retrieved by converting to a wig track, default: off)\n";
 $usage .= "  --nomult           do not summarize multiple identical intron hints to a single one\n";
 $usage .= "  --remove_redundant only keep the strongest hint for a region (default false)\n";
 $usage .= "  --maxcoverage=n    maximal number of hints at a given position. A high value causes long running time of\n";
--- a/scripts/evalCGP.pl
+++ b/scripts/evalCGP.pl
@@ -134,7 +134,7 @@
     die ("eval is not executable. Please add the directory which contains the executable evaluate_gtf.pl to the PATH environment variable or specify the path with --eval_exec_dir.");
 }
 if (qx("$cmdpars{'eval_exec_dir'}evaluate_gtf.pl" 2>&1) =~ /^Can\'t\slocate\s(\w+\.pm)/ ){
-    die ("eval is not executable. The perl libary " . $1 . " cannot be located.\n" . 
+    die ("eval is not executable. The perl library " . $1 . " cannot be located.\n" . 
 	 "Please add the directory which contains " . $1 . " to the PERL5LIB environment variable, e.g. add the following line to your .bashrc file:\n\n" . 
 	 "export PERL5LIB=\$PERL5LIB:/path/to/" . $1 . "\n\n");
 }
--- a/scripts/optimize_augustus.pl
+++ b/scripts/optimize_augustus.pl
@@ -198,7 +198,7 @@
 	die ("eval is not executable. Please add the directory which contains the executable evaluate_gtf.pl to the PATH environment variable or specify the path with --eval_exec_dir.");
     }
     if (qx("$cmdpars{'eval_exec_dir'}evaluate_gtf.pl" 2>&1) =~ /^Can\'t\slocate\s(\w+\.pm)/ ){
-	die ("eval is not executable. The perl libary " . $1 . " cannot be located.\n" . 
+	die ("eval is not executable. The perl library " . $1 . " cannot be located.\n" . 
              "Please add the directory which contains " . $1 . " to the PERL5LIB environment variable, e.g. add the following line to your .bashrc file:\n\n" . 
 	     "export PERL5LIB=\$PERL5LIB:/path/to/" . $1 . "\n\n");
     }
--- a/scripts/partition_gtf2gb.pl
+++ b/scripts/partition_gtf2gb.pl
@@ -147,7 +147,7 @@
 	    $_=~s/^>//; # remove the leading header sign
 	    $seqName=$_;
 	    if(defined($seq{$seqName})){
-		die("ERROR: the same sequence name occured twice in the genome file $fname!\n");
+		die("ERROR: the same sequence name occurred twice in the genome file $fname!\n");
 	    }
 	}else{	
 	    chomp $_;
--- a/scripts/simplifyFastaHeaders.pl
+++ b/scripts/simplifyFastaHeaders.pl
@@ -25,7 +25,7 @@
 while(<INPUT>){
     if(not($_=~m/\n$/)){
         if($wrongNL < 1){
-            print STDERR "Warning: something seems to be wrong with the newline character! This is likely to cause problems with the autoAug.pl pipeline and the AUGUSTUS web service! Please adapt your file to UTF8! This warning will be supressed from now on!\n";
+            print STDERR "Warning: something seems to be wrong with the newline character! This is likely to cause problems with the autoAug.pl pipeline and the AUGUSTUS web service! Please adapt your file to UTF8! This warning will be suppressed from now on!\n";
             $wrongNL++;
         }
     }
@@ -51,7 +51,7 @@
 	    }
 	}else{
 	    if($emptyC < 1){
-		print STDERR "Warning: empty line was removed! This warning will supressed from now on!\n";
+		print STDERR "Warning: empty line was removed! This warning will suppressed from now on!\n";
 	    } 
 	    $emptyC++;
 	}
--- a/src/consensus.cc
+++ b/src/consensus.cc
@@ -647,7 +647,7 @@
     cout<<max_line_len<<'\t'<<max_freq<<endl;
     cout<< " The scale is "<< (float)max_line_len/max_freq <<" * = one occurence"<< endl;
     if(starting==0)
-      cout <<" and it starts from begining of sequence." <<endl;
+      cout <<" and it starts from beginning of sequence." <<endl;
     else
       cout <<" and it begins from position "<< starting <<"."<<endl;
     for(j=0;j<max_string_length;j++){      
--- a/src/exon_seg.cc
+++ b/src/exon_seg.cc
@@ -377,11 +377,11 @@
     /* Initialize the vector to store the smooth data
      */
     smooth_data.resize(input_set[0][0].size(),0.0);
-    /* For the begining the code is written just to wrok on the
+    /* For the beginning the code is written just to wrok on the
      * first track of the + strand only
      */
     for(l=0;l<smooth_data.size();l++){// loop over position on track
-      /* Dont change the values for the begining values and end values
+      /* Dont change the values for the beginning values and end values
        * which cannot be covered by the window
        */
       if(l<moving_window/2){
--- a/src/geneMSA.cc
+++ b/src/geneMSA.cc
@@ -841,7 +841,7 @@
 void GeneMSA::computeOmegasEff(vector<AnnoSequence*> const &seqRanges, PhyloTree *ctree, ofstream *codonAli) {
     cout<<"computing omega for each ortho exon."<<endl;
 
-    // treat forward and reverse strand seperately (might be done more efficiently)
+    // treat forward and reverse strand separately (might be done more efficiently)
     for (int strnd=1; strnd>=0; strnd--){
 	bool plusStrand = (bool) strnd;
 	if (plusStrand){
@@ -1023,7 +1023,7 @@
 		currRFnum = coit->second.size() - 1;
 	      }
 	      
-	      // store cumulative values at the begining of an OrthoExon
+	      // store cumulative values at the beginning of an OrthoExon
 	      cumValues cv = coit->second[currRFnum].second;
 	      
 	      aliPosIt->second.oeStart[i]->setOmega(&cv.logliks, codonevo, true);
--- a/src/introntrain.cc
+++ b/src/introntrain.cc
@@ -357,7 +357,7 @@
 			      cerr << e.getMessage() << endl;
 			  } 
 			  if (numErrorSplicesites == 20) 
-			      cerr << "further detailed output of splice site errors supressed." << endl;
+			      cerr << "further detailed output of splice site errors suppressed." << endl;
 		      }
 		  }
 		  in = in->next;
--- a/auxprogs/homGeneMapping/src/genome.cc
+++ b/auxprogs/homGeneMapping/src/genome.cc
@@ -294,7 +294,7 @@
 	    map<uint_fast64_t, vector< list< uint_fast64_t > > >::iterator it;
 	    it = mappedPos.find(key);                                                                                                 
 	    if(it == mappedPos.end())
-		throw ProjectError("internal error: unkown SeqIntKey" + itoa(key) + " in genome " + name + "\n");
+		throw ProjectError("internal error: unknown SeqIntKey" + itoa(key) + " in genome " + name + "\n");
 	    it->second[other.getIdx()].push_back(mapped.getKey());
 	}
     }
@@ -320,7 +320,7 @@
 
     map<int,string>::const_iterator it = seqIDs.find(seqID);                                                                                                 
     if(it == seqIDs.end())
-	throw ProjectError("internal error: unkown sequence ID seqID=" + itoa(seqID) + " in genome " + name + "\n");
+	throw ProjectError("internal error: unknown sequence ID seqID=" + itoa(seqID) + " in genome " + name + "\n");
     return it->second;
 
 }
@@ -425,7 +425,7 @@
     map<uint_fast64_t, vector< list< uint_fast64_t > > >::iterator it;
     it = mappedPos.find(seqInt.getKey());                                                                                                 
     if(it == mappedPos.end())
-	throw ProjectError("internal error: unkown SeqIntKey" + itoa(seqInt.getKey()) + " in genome " + name + "\n");
+	throw ProjectError("internal error: unknown SeqIntKey" + itoa(seqInt.getKey()) + " in genome " + name + "\n");
     return it->second;
 }
 
--- a/auxprogs/joingenes/joingenes.cpp
+++ b/auxprogs/joingenes/joingenes.cpp
@@ -81,7 +81,7 @@
     cout << "      Secondary program functions:" << endl;
     cout << "\t--onlycompare\t\t\t-c\t\t\tis a flag." << endl;
     cout << "\t\t\t\t\t\t\t\tIf this flag is set, it disables the normal function of the program and" << endl;
-    cout << "\t\t\t\t\t\t\t\tactivates a compare and seperate mode to seperate equal transcripts from non equal ones." << endl;
+    cout << "\t\t\t\t\t\t\t\tactivates a compare and separate mode to separate equal transcripts from non equal ones." << endl;
     cout << endl;
     cout << "      This help:" << endl;
     cout << "\t--help \t\t\t\t-h\t\t\tprints the help documentation." << endl;
--- a/include/properties.hh
+++ b/include/properties.hh
@@ -118,7 +118,7 @@
  *      methods, where TYPE is one of Int, Double, Bool or String. 
  *
  *      The format of the properties file is line based. Each line contains
- *      the property name and the property value, seperated by whitespaces.
+ *      the property name and the property value, separated by whitespaces.
  *      Comments begin with a '#' and end an the end of line.
  *
  *      Example: Listing of a properties file

--- a/auxprogs/joingenes/jg_transcript.cpp
+++ b/auxprogs/joingenes/jg_transcript.cpp
@@ -250,7 +250,7 @@
 }
 
 double simpleProkScore(Transcript const* tx){
     // calculates a score for comparision; completeness shouldnt be used
     if (tx->exon_list.size() != 1)
 	return 0;
     else
@@ -938,7 +938,7 @@
     temp_exon_list.clear();
     switch (fittingCase){
     case 0:
-	cerr << "WARNING: shouldnt happen (in joining())!" << endl;
+	cerr << "WARNING: shouldn't happen (in joining())!" << endl;
 	break;
     case 1:
 	if (strand == '+'){
@@ -1941,7 +1941,7 @@
     if (properties.warningCount[warningString] <= n){
         cerr << "WARNING: " << warning << endl;
 	if (properties.warningCount[warningString] == n){
-	    cerr << "(This problem occured already " << n << " times and will not be printed further)..." << endl;
+	    cerr << "(This problem occurred already " << n << " times and will not be printed further)..." << endl;
 	}
     }
 }
@@ -1949,7 +1949,7 @@
 void warningSummary(string const &warning, string const &warning2, Properties &properties, string warningString){
     if (properties.warningCount[warningString] == 0){return;}
     if (warning.empty()){
-	cerr << "The " << warningString << " problem occured " << properties.warningCount[warningString] << " times." << endl;
+	cerr << "The " << warningString << " problem occurred " << properties.warningCount[warningString] << " times." << endl;
     }else{
 	cerr << warning << properties.warningCount[warningString] << warning2 << endl;
     }
@@ -250,7 +250,7 @@
 
 double simpleProkScore(Transcript const* tx){
-    // calculates a score for comparision; completeness shouldnt be used
+    // calculates a score for comparision; completeness shouldn't be used
     if (tx->exon_list.size() != 1)
 	return 0;